==> v0.4.9.zip: libarea/app/Languages/zh_CN/app.php <==
<?php

/*注意--语言 已修改 278
* The following language strings are used to translate the site core 
* (controllers and templates).
*
* Следующие языковые строки используются для переводя ядра сайта 
* (контроллеры и шаблоны).
*/

return [
    'home'              => '主页',
    'catalog'           => '目录',
    'feed'              => '主题',
    'test'              => '测试',
    'hi'                => '嗨',
    'news'              => '新闻',
    'team'              => '团队',
    'teams'             => '团队',
    'owner'             => '所有者',
    'top'               => '最佳',
    'admin'             => '管理',
    'well'              => '好',
    'development'       => '开发',
    'sort'              => '分类',
    'facets'            => '部分',
    'content'           => '內容',
    'navigation'        => '导航',
    'category'          => '类别',
    'visibility'        => '可见性',
    'number'            => '数字/编号',
    'icon'              => '图标',
    'template'          => '模板',
    'setting'           => '设置',
    'settings'          => '设置',
    'security'          => '密码',
    'avatar'            => '头像',
    'understands'       => '我明白',
    'necessarily'       => '必填',
    'create'            => '撰写',
    'writers'           => '作者',
    'by_deposit'        => '按贡献量',
    'welcome'           => '欢迎',
    'create_account'    => '注册帐号',
    'saw'               => '格言',
    'bodies'            => '团体',
    'thanks'            => '谢谢',
    'whisper'           => '悄悄话',
    'report'            => '举报',
    'reports'           => '举报',
    'time'              => '时间',
    'deleted'           => '已删除',
    'remote'            => '冷门',
    'like'              => '喜欢',
    'recommended'       => '推荐',
    'notification'      => '通知',
    'notifications'     => '通知',
    'preferences'       => '優先首选项',
    'action'            => '动作',
    'domain'            => '领域',
    'domains'           => '领域',
    'blog'              => '博客',
    'blogs'             => '博客',
    'topics'            => '话题',
    'topic'             => '主题',
    'parent'            => '总部',
    'authorization'     => '授权',
    'sign_in'           => '登入',
    'sign_out'          => '登出',
    'registration'      => '注册',
    'advertising'       => '广告',
    'private_messages'  => '私人消息',
    'post_merged'       => '帖子合并',
    'post_appearance'   => '帖子外观',
    'id_merged_post'    => '此帖子将与之合并的帖子的 ID',
    'post_merged_info'  => '这是重要的一步。手动查找 ID，或 0 - 取消合并',
    'it_read'           => '已读',
    'all_messages'      => '所有消息',
    'send_message'      => '对话',
    'dialogues'         => '对话',
    'dialogue'          => '发送消息',
    'write_message'     => '写消息',
    'send'              => '发送',
    'information'       => '信息',
    'donate'            => '支持项目',
    'review'            => '审查',
    'contacts'          => '联系方式',
    'city'              => '城市',
    'remember_me'       => '记住我',
    'banned'            => '禁止',
    'ban_it'            => '禁止',
    'unban'             => '解禁',
    'reset'             => '重置',
    'invited_guests'    => '受邀',
    'nickname'          => '昵称',
    'name'              => '名称',
    'password'          => '密码',
    'new_password'      => '新密码',
    'repeat'            => '重复',
    'show'              => '显示',
    'new'               => '新密',
    'new_ones'          => '新的',
    'old'               => '旧密码',
    'code'              => '代码',
    'invite'            => '邀请',
    'invites'           => '邀请',
    'view'              => '查看',
    'views'             => '浏览',
    'profile'           => '概述',
    'title'             => '标题',
    'seo_title'         => '标题（用于 SEO）',
    'heading'           => '题目',
    'to_extract'        => '摘录',
    'discussion'        => '讨论',
    'description'       => '描述',
    'meta_description'  => '元描述',
    'short_description' => '简短描述',
    'favorites'         => '书签',
    'long'              => '长',
    'created_by'        => '已创建',
    'help'              => '帮助',
    'statistics'        => '统计',
    'privacy'           => '隐私',
    'about'             => '关于',
    'about_me'          => '关于我',
    'riddle'            => '猜谜语',
    'more'              => '更多',
    'see_more'          => '查看更多',
    'read_more'         => '阅读更多',
    'crop_post'         => '作物柱',
    'other'             => '其他',
    'official'          => '关闭',
    'community'         => '社区',
    'trust_level'       => '信任等级',
    'search'            => '搜索',
    'find'              => '寻找',
    'up'                => '向上',
    'user'              => '用户',
    'users'             => '成员',
    'page'              => '页',
    'read'              => '阅读',
    'reads'             => '阅读次数',
    'reading'           => '我阅读的',
    'is_reading'        => '正在阅读',
    'subscribed'        => '签名',
    'unsubscribed'      => '已退订',
    'unsubscribe'       => '退订',
    'subscribe'         => '订阅',
    'approved'          => '已批准',
    'remove'            => '刪除',
    'recover'           => '重建',
    'download'          => '下载',
    'password_recovery' => '找回密码',
    'draft_post'        => '这是草稿帖吗',
    'drafts'            => '草稿',
    'cancel'            => '取消',
    'reply'             => '回复',
    
    // Редактор
    'foto'              => '照片',
    'bold'              => '粗体',
    'strikethrough'     => '删除线',
    'italic'            => '斜体',
    'quote'             => '引用',
    'link'              => '链接',
    'preview'           => '预览',
    'toggle_two'        => '双窗口',
    'fullscreen'        => '全屏',
    'spoiler'           => '剧透',
    'spoiler_auth'      => '仅限授权用户',
    'select_image'      => '请选择图像',
    'drop_image'        => '拖放图像上传',
    'attach_files'      => '可从剪贴板粘贴文件',

    'view_policy'       => '只有会员才能看到内容',
    'entry_policy'      => '批准新成员',
 
    'back'              => '返回',
    'edit'              => '更改',
    'save'              => '保存',
    'add'               => '添加',
    'add_post'          => '添加帖子',
    'add_topic'         => '添加主题',
    'add_blog'          => '添加博客',
    'add_category'      => '添加类别',
    'edit_category'     => '更改类别',
    'edit_post'         => '编辑帖子',
    'edit_topic'        => '更改主题',
    'edit_blog'         => '编辑博客',
    'edit_page'         => '编辑页面',
    'edit_section'      => '编辑部分',
    
    'published'         => '發表於',

    'being_developed'   => '开发中',
    'activity'          => '活动',
    'question'          => '问题',
    'questions'         => '问题',
    'question_closed'   => '问题已结束',
    'this_draft'        => '这篇文章是草稿',
    'no_cover'          => '还没有封面',
    'no_invites'        => '你还没有创建邀请',
    'no_content'        => '不幸的是，还没有内容',
    'no_dialogs'        => '不幸的是，还没有对话',    
    'no_posts'          => '不幸的是，还没有帖子',
    'no_favorites'      => '不幸的是，还没有书签',
    'no_comments'       => '不幸的是，还没有评论',
    'no_answers'        => '不幸的是，还没有回复',
    'default'           => '默认',
    'qa'                => '问答',
    'answered'          => '已回答',
    'post_translation'  => '帖子是翻译',
    'translation'       => '翻译',
    'format_Q&A'        => '这是一个问题（将成为问答形式）',
    'pin'               => '置顶此帖',
    
    'source'            => '来源',
    'website'           => '网站',
    'websites'          => '网站',
    'sites'             => '站点',
    'related'           => '相关',
    'related_posts'     => '相关帖子',
    'parents'           => '父',
    'children'          => '子',
    'bound_children'    => '相关(子)',
    'bound_parents'     => '相关(父)',
    'root'              => 'Root',
    'root_help'         => '顶部(主)树主题',
    'upper'             => '上层',
    'subtopics'         => '子主题',
    'badge'             => '徽章',
    'badges'            => '徽章',
    'reward_user'       => '奖赏用户',
    'for_example'       => '例如',
    'ed'                => '改编',
    'there_are'         => '同意',
    'yes'               => '是',
    'no'                => '否',
    'all'               => '全部',
    'alls'              => '所有人',
    'you'               => '你',
    'from'              => '从',
    'by'                => '由',
    'in'                => '在',
    'and'               => '和',
    'on'                => '上',
    'for'               => '为',
    'my'                => '我的',
    'publications'      => '刊物及刊物',
    'posted'            => '已发布',
    'selected_post'     => '精选帖子',
    'color'             => '颜色',
    'text'              => '文本',
    'author'            => '作者',
    'characters'        => '个字符',
    'markdown'          => '支持Markdown',
    'write'             => '撰写',
    'in_profile'        => '在个人资料中',
    'request'           => '请求',
    'results'           => '结果',
    'format_cover_post' => '宽度，500px以上。方向水平',

    'close'             => '关闭',
    'post_closed'       => '该帖子已关闭',
    'repeat_password'   => '重复密码',
    'forgot_password'   => '忘记密码',
    'rules'             => '网站规则',
    'restriction'       => '限制',
    
    'text_closed'       => '未经授权禁止查看此隐藏文本',

    /* Дата и время + события */
    'months'        => ['', '1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月','10月', '11月', '12月'],
    'today'         => '今天',
    'yesterday'     => '昨天',

    'num_message'=>['消息','消息','消息'],
    'num_answer'=>['回复','回复','回复'],
    'num_post'=>['帖子','帖子','帖子'],
    'num_view'=>['查看','查看','查看'],
    'num_up'=>['喜欢','喜欢','喜欢'],

    'comment'       => '评论',
    'comments'      => '评论',
    'answer'        => '回复',
    'answers'       => '回复',
    'message'       => '消息',
    'messages'      => '消息',
    'post'          => '帖子',
    'posts'         => '帖子',

    'language'          => '语言',
    'ru_language'       => '俄语',
    'ua_language'       => '乌克兰',
    'en_language'       => '英语',
    'de_language'       => '德语',
    'fr_language'       => '法语',
    'zh_TW_language'    => '繁体中文',
    'zh_CN_language'    => '简体中文',
    'ro_language'       => '罗马尼亚语',

    'type'              => '类型',
    'logo'              => '标志',
    'last'              => '最后一次',
    'recommended_size'  => '建议尺寸',

    'you_answered'      => '你已经回答了此问题',
    'need_login'        => '你需要登录',
    'no_auth'           => '要回答，你需要<a href="/login">登录</a>',
    'auth_comm'         => '你必须登录才能发表评论',
    'not_registered'    => '发帖，回复，评论... <br>你还没有注册',
    'invalid'           => '无效',
    'agree_rules'       => '继续，即表示你同意<a href="/info/article/privacy">使用条款</a>',
    'limit_content'     => '你已用尽在网站上添加的限制',
    'reg_invite'        => '邀请注册',
    'details_here'      => '详情如下',
    'breaking_rules'    => '违反规则',

    'section'           => '部分',
    'tag'               => '标签',
    'tags'              => '标签',
    'folder'            => '文件夹',
    'folders'           => '文件夹',
    'folders_s'         => '文件夹',
    'pages'             => '页面',
    'go_to'             => '转到',
    'seo'               => 'SEO',
    'url'               => '网址',
    'url_parsing'       => '文章 URL（用于解析）',
    'slug'              => '别名',
    'email'             => '邮箱',
    'wiki'              => 'Wiki',
    'edit_answer'       => '让我们更改答复',
    'enter'             => '输入',
    'enter_password'    => '输入密码',

    'rec_posts'         => '推荐帖子',
    'rec_posts_desc'    => '手动选择"{name}"中推荐的帖子',
    'topic_subs'        => '订阅主题并在提要中阅读',
    'i_read'            => '我看过',
 
    'message_PM'        => '当PM消息到来时',
    'appeal_@'          => '当通过@联系我时',

    'audits'            => '审核',
    'limits_invitation' => '你的信任程度还不允许你使用邀请',
    'can_send_link'     => '你可以发送此链接',
    'link_used'         => '链接已使用',
    'medal_reg'         => '注册奖章',
    'registered'        => '已注册',
    'invitations_left'  => '剩余邀请',

    'first_days'        => '在社区上线初期加入',
    'nickname_replay'   => '这个昵称已在网站上使用',

    'english'           => '英语',
    'post_page'         => '如果填写，帖子将是一个页面(在文档中)',
    'work_email'        => '工作邮箱(用于<b>帐户激活</b>)',

    'view_post_tl'      => '谁可以查看帖子(从哪个TL)',
    'invited_you'       => '你是由本网站成员邀请的。输入邀请',
    'invite_features'   => '你可以邀请朋友',

    'content_deleted'   => '{name} 已删除',

    'endless_scroll'        => '启用无限滚动？',
    'notification_email'    => '通过邮件通知',
    'notifications_limit'   => '显示最后100条通知',

    /* 通知和日志 */
    'notif_add_pm'              => '给你写了一个{url}私信{a}',
    'notif_add_comment'         => '评论{url}你的消息{a}',
    'notif_add_comment_comment' => '答复了{url}你的评论{a}',
    'notif_add_answer'          => '答复了{url}你的帖子{a}',
    'notif_add_flag'            => '收到{url}一条投诉{a}',
    'notif_add_audit'           => '需要{url}内容审核{a}',
    'notif_references_post'     => '在{url}帖子{a}中提到你',
    'notif_references_amswer'   => '在{url}消息{a}中提到你',
    'notif_references_comment'  => '在{url}评论{a}中提到过你',
    'notif_add_website'         => '添加站点，{url}查一下{a}',
    'notif_edit_website'        => '更改站点，{url}检查它{a}',
    'notif_approved_website'    => '(主持人){url}更改(批准)你的网站{a}',
    'notif_add_website_comment' => '{url}在你订阅的网站{a}上发表评论',

];

==> v0.5.0.zip: libarea/app/Languages/zh_CN/app.php <==
<?php

/*注意--语言 已修改 278
* The following language strings are used to translate the site core 
* (controllers and templates).
*
* Следующие языковые строки используются для переводя ядра сайта 
* (контроллеры и шаблоны).
*/

return [
    'home'              => '主页',
    'catalog'           => '目录',
    'feed'              => '主题',
    'test'              => '测试',
    'hi'                => '嗨',
    'news'              => '新闻',
    'team'              => '团队',
    'teams'             => '团队',
    'owner'             => '所有者',
    'top'               => '最佳',
    'admin'             => '管理',
    'well'              => '好',
    'development'       => '开发',
    'sort'              => '分类',
    'facets'            => '部分',
    'content'           => '內容',
    'navigation'        => '导航',
    'category'          => '类别',
    'visibility'        => '可见性',
    'number'            => '数字/编号',
    'icon'              => '图标',
    'template'          => '模板',
    'setting'           => '设置',
    'settings'          => '设置',
    'security'          => '密码',
    'avatar'            => '头像',
    'understands'       => '我明白',
    'necessarily'       => '必填',
    'create'            => '撰写',
    'writers'           => '作者',
    'by_deposit'        => '按贡献量',
    'welcome'           => '欢迎',
    'create_account'    => '注册帐号',
    'saw'               => '格言',
    'bodies'            => '团体',
    'thanks'            => '谢谢',
    'whisper'           => '悄悄话',
    'report'            => '举报',
    'reports'           => '举报',
    'time'              => '时间',
    'deleted'           => '已删除',
    'remote'            => '冷门',
    'like'              => '喜欢',
    'recommended'       => '推荐',
    'notification'      => '通知',
    'notifications'     => '通知',
    'preferences'       => '優先首选项',
    'action'            => '动作',
    'domain'            => '领域',
    'domains'           => '领域',
    'blog'              => '博客',
    'blogs'             => '博客',
    'topics'            => '话题',
    'topic'             => '主题',
    'parent'            => '总部',
    'authorization'     => '授权',
    'sign_in'           => '登入',
    'sign_out'          => '登出',
    'registration'      => '注册',
    'advertising'       => '广告',
    'private_messages'  => '私人消息',
    'post_merged'       => '帖子合并',
    'post_appearance'   => '帖子外观',
    'id_merged_post'    => '此帖子将与之合并的帖子的 ID',
    'post_merged_info'  => '这是重要的一步。手动查找 ID，或 0 - 取消合并',
    'it_read'           => '已读',
    'all_messages'      => '所有消息',
    'send_message'      => '对话',
    'dialogues'         => '对话',
    'dialogue'          => '发送消息',
    'write_message'     => '写消息',
    'send'              => '发送',
    'information'       => '信息',
    'donate'            => '支持项目',
    'review'            => '审查',
    'contacts'          => '联系方式',
    'city'              => '城市',
    'remember_me'       => '记住我',
    'banned'            => '禁止',
    'ban_it'            => '禁止',
    'unban'             => '解禁',
    'reset'             => '重置',
    'invited_guests'    => '受邀',
    'nickname'          => '昵称',
    'name'              => '名称',
    'password'          => '密码',
    'new_password'      => '新密码',
    'repeat'            => '重复',
    'show'              => '显示',
    'new'               => '新密',
    'new_ones'          => '新的',
    'old'               => '旧密码',
    'code'              => '代码',
    'invite'            => '邀请',
    'invites'           => '邀请',
    'view'              => '查看',
    'views'             => '浏览',
    'profile'           => '概述',
    'title'             => '标题',
    'seo_title'         => '标题（用于 SEO）',
    'heading'           => '题目',
    'to_extract'        => '摘录',
    'discussion'        => '讨论',
    'description'       => '描述',
    'meta_description'  => '元描述',
    'short_description' => '简短描述',
    'favorites'         => '书签',
    'long'              => '长',
    'created_by'        => '已创建',
    'help'              => '帮助',
    'statistics'        => '统计',
    'privacy'           => '隐私',
    'about'             => '关于',
    'about_me'          => '关于我',
    'riddle'            => '猜谜语',
    'more'              => '更多',
    'see_more'          => '查看更多',
    'read_more'         => '阅读更多',
    'crop_post'         => '作物柱',
    'other'             => '其他',
    'official'          => '关闭',
    'community'         => '社区',
    'trust_level'       => '信任等级',
    'search'            => '搜索',
    'find'              => '寻找',
    'up'                => '向上',
    'user'              => '用户',
    'users'             => '成员',
    'page'              => '页',
    'read'              => '阅读',
    'reads'             => '阅读次数',
    'reading'           => '我阅读的',
    'is_reading'        => '正在阅读',
    'subscribed'        => '签名',
    'unsubscribed'      => '已退订',
    'unsubscribe'       => '退订',
    'subscribe'         => '订阅',
    'approved'          => '已批准',
    'remove'            => '刪除',
    'recover'           => '重建',
    'download'          => '下载',
    'password_recovery' => '找回密码',
    'draft_post'        => '这是草稿帖吗?',
    'drafts'            => '草稿',
    'cancel'            => '取消',
    'reply'             => '回复',
    
    // Редактор
    'foto'              => '照片',
    'bold'              => '粗体',
    'strikethrough'     => '删除线',
    'italic'            => '斜体',
    'quote'             => '引用',
    'link'              => '链接',
    'preview'           => '预览',
    'toggle_two'        => '双窗口',
    'fullscreen'        => '全屏',
    'spoiler'           => '剧透',
    'spoiler_auth'      => '仅限授权用户',
    'select_image'      => '请选择图像',
    'drop_image'        => '拖放图像上传',
    'attach_files'      => '可从剪贴板粘贴文件',

    'view_policy'       => '只有会员才能看到内容',
    'entry_policy'      => '批准新成员',
 
    'back'              => '返回',
    'edit'              => '更改',
    'save'              => '保存',
    'add'               => '添加',
    'add_post'          => '添加帖子',
    'add_topic'         => '添加主题',
    'add_blog'          => '添加博客',
    'add_category'      => '添加类别',
    'edit_category'     => '更改类别',
    'edit_post'         => '编辑帖子',
    'edit_topic'        => '更改主题',
    'edit_blog'         => '编辑博客',
    'edit_page'         => '编辑页面',
    'edit_section'      => '编辑部分',
    
    'published'         => '發表於',

    'being_developed'   => '开发中',
    'activity'          => '活动',
    'question'          => '问题',
    'questions'         => '问题',
    'question_closed'   => '问题已结束',
    'this_draft'        => '这篇文章是草稿',
    'no_cover'          => '还没有封面',
    'no_invites'        => '你还没有创建邀请',
    'no_content'        => '不幸的是，还没有内容',
    'no_dialogs'        => '不幸的是，还没有对话',    
    'no_posts'          => '不幸的是，还没有帖子',
    'no_favorites'      => '不幸的是，还没有书签',
    'no_comments'       => '不幸的是，还没有评论',
    'no_answers'        => '不幸的是，还没有回复',
    'default'           => '默认',
    'qa'                => '问答',
    'best_answer'       => '最佳答案',
    'answered'          => '已回答',
    'post_translation'  => '帖子是翻译?',
    'translation'       => '翻译',
    'format_Q&A'        => '这是一个问题（将成为问答形式）?',
    'pin'               => '置顶此帖?',
    
    'source'            => '来源',
    'website'           => '网站',
    'websites'          => '网站',
    'sites'             => '站点',
    'related'           => '相关',
    'related_posts'     => '相关帖子',
    'parents'           => '父',
    'children'          => '子',
    'bound_children'    => '相关(子)',
    'bound_parents'     => '相关(父)',
    'root'              => 'Root',
    'root_help'         => '顶部(主)树主题',
    'upper'             => '上层',
    'subtopics'         => '子主题',
    'badge'             => '徽章',
    'badges'            => '徽章',
    'reward_user'       => '奖赏用户',
    'for_example'       => '例如',
    'ed'                => '改编',
    'there_are'         => '同意',
    'yes'               => '是',
    'no'                => '否',
    'all'               => '全部',
    'alls'              => '所有人',
    'you'               => '你',
    'from'              => '从',
    'by'                => '由',
    'in'                => '在',
    'and'               => '和',
    'on'                => '上',
    'for'               => '为',
    'my'                => '我的',
    'publications'      => '刊物及刊物',
    'posted'            => '已发布',
    'selected_post'     => '精选帖子',
    'color'             => '颜色',
    'text'              => '文本',
    'author'            => '作者',
    'characters'        => '个字符',
    'markdown'          => '支持Markdown',
    'write'             => '撰写',
    'in_profile'        => '在个人资料中',
    'request'           => '请求',
    'results'           => '结果',
    'format_cover_post' => '宽度，500px以上。方向水平',

    'close'             => '关闭',
    'post_closed'       => '该帖子已关闭 ?',
    'repeat_password'   => '重复密码',
    'forgot_password'   => '忘记密码',
    'rules'             => '网站规则',
    'restriction'       => '限制',
    
    'text_closed'       => '未经授权禁止查看此隐藏文本',

    /* Дата и время + события */
    'months'        => ['', '1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月','10月', '11月', '12月'],
    'today'         => '今天',
    'yesterday'     => '昨天',

    'num_message'=>['消息','消息','消息'],
    'num_answer'=>['回复','回复','回复'],
    'num_post'=>['帖子','帖子','帖子'],
    'num_view'=>['查看','查看','查看'],
    'num_up'=>['喜欢','喜欢','喜欢'],

    'comment'       => '评论',
    'comments'      => '评论',
    'answer'        => '回复',
    'answers'       => '回复',
    'message'       => '消息',
    'messages'      => '消息',
    'post'          => '帖子',
    'posts'         => '帖子',

    'language'          => '语言',
    'ru_language'       => '俄语',
    'ua_language'       => '乌克兰',
    'en_language'       => '英语',
    'de_language'       => '德语',
    'fr_language'       => '法语',
    'zh_TW_language'    => '繁体中文',
    'zh_CN_language'    => '简体中文',
    'ro_language'       => '罗马尼亚语',
    'ar_language'       => '阿拉伯',

    'type'              => '类型',
    'logo'              => '标志',
    'last'              => '最后一次',
    'recommended_size'  => '建议尺寸',

    'you_answered'      => '你已经回答了此问题',
    'need_login'        => '你需要登录',
    'no_auth'           => '要回答，你需要<a href="/login">登录</a>',
    'auth_comm'         => '你必须登录才能发表评论',
    'not_registered'    => '发帖，回复，评论... <br>你还没有注册',
    'invalid'           => '无效',
    'agree_rules'       => '继续，即表示你同意<a href="/info/article/privacy">使用条款</a>',
    'limit_content'     => '你已用尽在网站上添加的限制',
    'reg_invite'        => '邀请注册',
    'details_here'      => '详情如下',
    'breaking_rules'    => '违反规则',

    'section'           => '部分',
    'tag'               => '标签',
    'tags'              => '标签',
    'folder'            => '文件夹',
    'folders'           => '文件夹',
    'folders_s'         => '文件夹',
    'pages'             => '页面',
    'go_to'             => '转到',
    'seo'               => 'SEO',
    'url'               => '网址',
    'url_parsing'       => '文章 URL（用于解析）',
    'slug'              => '别名',
    'email'             => '邮箱',
    'wiki'              => 'Wiki',
    'edit_answer'       => '让我们更改答复',
    'enter'             => '输入',
    'enter_password'    => '输入密码',

    'rec_posts'         => '推荐帖子',
    'rec_posts_desc'    => '手动选择"{name}"中推荐的帖子',
    'topic_subs'        => '订阅主题并在提要中阅读',
    'i_read'            => '我看过',
 
    'message_PM'        => '当PM消息到来时',
    'appeal_@'          => '当通过@联系我时',

    'audits'            => '审核',
    'limits_invitation' => '你的信任程度还不允许你使用邀请',
    'can_send_link'     => '你可以发送此链接',
    'link_used'         => '链接已使用',
    'medal_reg'         => '注册奖章',
    'registered'        => '已注册',
    'invitations_left'  => '剩余邀请',

    'first_days'        => '在社区上线初期加入',
    'nickname_replay'   => '这个昵称已在网站上使用',

    'english'           => '英语',
    'post_page'         => '如果填写，帖子将是一个页面(在文档中)',
    'work_email'        => '工作邮箱(用于<b>帐户激活</b>)',

    'view_post_tl'      => '谁可以查看帖子(从哪个TL)',
    'invited_you'       => '你是由本网站成员邀请的。输入邀请',
    'invite_features'   => '你可以邀请朋友',

    'content_deleted'   => '{name} 已删除',

    'endless_scroll'        => '启用无限滚动？',
    'notification_email'    => '通过邮件通知',
    'notifications_limit'   => '显示最后100条通知',

    'ignored'               => '忽略',  
    'ignored_users'         => '忽略的用户',
    'ignored_users_help'    => '您不会在提要中看到其帖子的用户。',
    'ignored_no'            => '您没有忽略的用户。', 

    /* 通知和日志 */
    'notif_add_pm'              => '给你写了一个{url}私信{a}',
    'notif_add_comment'         => '评论{url}你的消息{a}',
    'notif_add_comment_comment' => '答复了{url}你的评论{a}',
    'notif_add_answer'          => '答复了{url}你的帖子{a}',
    'notif_add_flag'            => '收到{url}一条投诉{a}',
    'notif_add_audit'           => '需要{url}内容审核{a}',
    'notif_references_post'     => '在{url}帖子{a}中提到你',
    'notif_references_amswer'   => '在{url}消息{a}中提到你',
    'notif_references_comment'  => '在{url}评论{a}中提到过你',
    'notif_add_website'         => '添加站点，{url}查一下{a}',
    'notif_edit_website'        => '更改站点，{url}检查它{a}',
    'notif_approved_website'    => '(主持人){url}更改(批准)你的网站{a}',
    'notif_add_website_comment' => '{url}在你订阅的网站{a}上发表评论',

];
